==> haskell-dlist-instances-0.1.1.1-214-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-JEmZoYwvns3JMjtKQqyqIi
key:                  dlist-instances-0.1.1.1-JEmZoYwvns3JMjtKQqyqIi
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  b78e4ecaf7cf5e68fc64e06ff87de66e
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist-instances
hs-libraries:         HSdlist-instances-0.1.1.1-JEmZoYwvns3JMjtKQqyqIi
depends:              base-4.16.4.0 dlist-1.0-3rGIivWoX8r4FDcy8caTmI
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-instances-0.1.1.1-215-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist-instances
version:              0.1.1.1
visibility:           public
id:                   dlist-instances-0.1.1.1-JslKp8mS5wKJOXBnE4qAqH
key:                  dlist-instances-0.1.1.1-JslKp8mS5wKJOXBnE4qAqH
license:              BSD-3-Clause
copyright:            2013 Greg Weber
maintainer:           Greg Weber <greg@gregweber.info>
author:               Greg Weber
homepage:             https://github.com/gregwebs/dlist-instances
synopsis:             Difference lists instances
description:
    See the dlist packages.
    This package is the canonical source for some orphan instances.
    Orphan instances are placed here to avoid dependencies elsewhere.

category:             Data
abi:                  c9fa1d64102314c698c87b3fd6139a45
exposed:              True
exposed-modules:      Data.DList.Instances
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dlist-instances-0.1.1.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dlist-instances-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dlist-instances
hs-libraries:         HSdlist-instances-0.1.1.1-JslKp8mS5wKJOXBnE4qAqH
depends:              base-4.16.4.0 dlist-1.0-HCxoMn9TirQDgPCFxho7O
haddock-interfaces:
    /usr/share/doc/haskell-dlist-instances/html/dlist-instances.haddock

haddock-html:         /usr/share/doc/haskell-dlist-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
